; Boards/AT91/BoardDefinesH.s
; Defines various constants and macros for the AT91 board
;
; 24/Dec/1999 ned

; BOARD_RETURNZPLOCATION determines location of HAL zero page
; Location of exception handlers
BOARD_EXCEPTHLOCATION		EQU	0x0
; Location of HAL r/w data
BOARD_HALZPLOCATION		EQU	0x40
; Location of UART ctrl blks
BOARD_HALZP_UARTSPACE		EQU	12288
; Location of L1 MMU page tables
BOARD_ARMMMU_L1PAGETABLES	EQU	16384				; 16k of L1 page tables


; Locations of UART zero page locations
HALZP_ANGELUARTSPACE		EQU	(0 * HALUARTBLK_SIZEOF)
HALZP_DEMONUARTSPACE		EQU	(1 * HALUARTBLK_SIZEOF)

; This macro is called to remap ROM to its proper place and offset the PC if necessary
	MACRO
	BOARD_MOVEROM

	MEND

; This macro is called to initialise DRAM for use (enable power to it, whatever)
	MACRO
	BOARD_INITIALISEDRAM

	MEND

; This macro is called to return the location of the zero page memory
; NOTE: This gets called in the general ISR so make it quick!
; It returns a pointer to at least 4k of zero page memory in R0
	MACRO
	BOARD_RETURNZPLOCATION $reg
	LDR	$reg,=(0x02080000 - 0x10000)		; 64k before mem end

	MEND

; This macro is called to build MMU tables for the board
; It returns a pointer to the MMU tables in R0
	MACRO
	BOARD_BUILDMMUTABLES
	; R9 is zero pages
	STMFD	R13!,{R1-R3}
	ADD	R0,R9,#BOARD_ARMMMU_L1PAGETABLES
	BL	ARMMMU_BeginL1PageTableBuild

	; Map 0x00000000 to 0x00200000 to same (ROM)
	MOV	R1,#0				; start Mb no
	MOV	R2,#0				; start desired virtual addr
	MOV	R3,#0x00200000			; end desired virtual addr
	MOV	R4,#0xa				; domain, access permissions, caching & buffering of section
	BL	ARMMMU_MakeL1PageTableEntries
	
	; Map 0x00200000 to 0x08000000 to Fault
	MOV	R3,#0x08000000			; end desired virtual addr
	MOV	R4,#0				; domain of section
	BL	ARMMMU_MakeL1PageTableEntries
	
	; Map 0x08000000 to 0x08200000 to 0xc0000000 (DRAM)
	MOV	R2,#0x08000000			; start desired virtual addr
	MOV	R3,#0x08200000			; end desired virtual addr
	MOV	R4,#0				; domain of section
	BL	ARMMMU_MakeL1PageTableEntries

	; Map 0x08200000 to 0x00000000 to Fault
	MOV	R3,#0x00000000			; end desired virtual addr
	MOV	R4,#0				; domain of section
	BL	ARMMMU_MakeL1PageTableEntries

	; Return addr of tables out in R0
	LDMFD	R13!,{R1-R3}
	MEND

; This macro is called to determine how much memory there is in application space (with the MMU enabled)
; It returns the base of memory in R0 and the top of memory in R1
	MACRO
	BOARD_RETURNMEMORYINFO

	MOV	R0,#0x02000000
	MOV	R1,#0x02080000

	MEND

; This macro is called to disable an unrecognised interrupt
; You have R0-R5 to play with
	MACRO
	BOARD_DISABLEUNKNOWNINTERRUPT

	MEND

; This macro is called to do any board-specific initialisations
; It is called just prior to calling NedHAL_Entry
; Keep within APCS regulations
	MACRO
	BOARD_INITIALISE
	IMPORT	AT91Timer_Initialise
	BL	AT91Timer_Initialise
	MEND

; This macro is called to do any board-specific shutdowns
; It is called when NedHAL_Entry returns
; Keep within APCS regulations
	MACRO
	BOARD_FINALISE
	IMPORT	AT91Timer_Finalise
	BL	AT91Timer_Finalise
	MEND


	END
